@@ -37,6 +37,7 @@ THE SOFTWARE.
 import os
 import sys
 
+from thor import schedule
 from thor.events import EventEmitter, on
 from thor.tcp import TcpServer
 
@@ -59,6 +60,7 @@ class HttpServer(EventEmitter):
         EventEmitter.__init__(self)
         self.tcp_server = self.tcp_server_class(host, port, loop=loop)
         self.tcp_server.on('connect', self.handle_conn)
+        schedule(0, self.emit, 'start')
 
     def handle_conn(self, tcp_conn):
         http_conn = HttpServerConnection(tcp_conn, self)
@@ -71,6 +73,7 @@ class HttpServer(EventEmitter):
         "Stop the server"
         # TODO: Finish outstanding requests w/ timeout?
         self.tcp_server.shutdown()
+        self.emit('stop')
 
 
 class HttpServerConnection(HttpMessageHandler, EventEmitter):
